Module process
tancore
0.16.0
Module process
Module Items
Functions
In crate tancore
tancore
Module
process
Functions

import_
lib_
process
process_
args
Return the process arguments as an array
process_
env_
vars
Return the process environment variables as a Map/Map.
process_
exec
Similar to C’s system function: The command specified by string is passed to the host environment to be executed by the command processor.
process_
exit
Terminates the current process with the specified exit code.
process_
foreign_
args
Return the process arguments as an array, includes the foreign (‘host’) arguments.
process_
shell
The command specified by string is passed to the host environment to be executed by the command processor. The STDOUT and STDERR of the process are ‘streamed’ to the caller STDOUT, STDERR.