process_shell

Function process_shell 

pub fn process_shell(args: &[Expr]) -> Result<Expr, Error>
The command specified by string is passed to the host environment to be executed by the command processor. The STDOUT and STDERR of the process are ‘streamed’ to the caller STDOUT, STDERR.