Module string

Module string 

Functions

char_to_upper_case
setup_lib_string
string_chars
Returns a char iterable for the chars in the string.
string_compare
string_constructor_from_chars
string_contains
string_ends_with
string_format
string_get_length
string_is_empty
string_new
string_pop
Removes the last character from the string buffer and returns it.
string_replace
string_slice
(slice str 2 5) (slice str 2) (slice str 2 -2) ; -2 is length - 2
string_slice_range
Cuts a slice out fo a string, defined by a range.
string_split
string_starts_with
string_to_lower_case
string_trim