Module process

Module process 

Functions

import_lib_process
process_args
Return the process arguments as an array
process_env_vars
Return the process environment variables as a Map/Map.
process_exec
Similar to C’s system function: The command specified by string is passed to the host environment to be executed by the command processor.
process_exit
Terminates the current process with the specified exit code.
process_foreign_args
Return the process arguments as an array, includes the foreign (‘host’) arguments.
process_shell
The command specified by string is passed to the host environment to be executed by the command processor. The STDOUT and STDERR of the process are ‘streamed’ to the caller STDOUT, STDERR.